@@ -74,6 +74,7 @@ require DynaLoader;
 
 my $v = MPFR_VERSION_MAJOR;
 if($v < 4) {
+  $Math::FakeDD::MPFR_PREC_MIN = 2;
   warn "
   This module requires that Math::MPFR was built against version 4
   of the mpfr C library. You have only ", Rmpfr_get_version, ".\n",
@@ -83,6 +84,7 @@ if($v < 4) {
   The need to use a 1-bit precision value is fairly limited, so
   we'll go ahead anyway. You have been warned !!\n";
 }
+else {   $Math::FakeDD::MPFR_PREC_MIN = 1 }
 
 my @tags = qw(
   NV_IS_DOUBLE NV_IS_DOUBLEDOUBLE NV_IS_QUAD NV_IS_80BIT_LD MPFR_LIB_VERSION
@@ -102,7 +104,7 @@ my @tags = qw(
 
 %Math::FakeDD::EXPORT_TAGS = (all => [@tags]);
 
-$Math::FakeDD::VERSION =  '1.02';
+$Math::FakeDD::VERSION =  '1.03';
 Math::FakeDD->DynaLoader::bootstrap($Math::FakeDD::VERSION);
 
 sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking
@@ -327,12 +329,13 @@ sub dd_repro {
   # AFAIK, this can happen only if the LSD is an integer power of 2.
   # Two examples: [0x1p+200 0x1p-549] & [0x1.ffffffffffff8p+999 0x1p-549].
 
-  my $can = mpfrtoa($mpfr);
+  my $candidate = mpfrtoa($mpfr);
   #my @frexp = dd_frexp($arg->{lsd});
-  if(abs( (dd_frexp($arg->{lsd}))[0]) == 0.5) {     # LSD is an integer power of 2.
-    my $ret = _chop_test($can, $arg, 1); # $ret will either be set to 'ok' (in which case
-                                         # we return $can), or $ret will be set to the
-                                         # correct value (in which case we return $ret).
+  if(abs( (dd_frexp($arg->{lsd}))[0]) == 0.5) { # LSD is an integer power of 2.
+
+    my $ret = _chop_test($candidate, $arg, 1); # $ret will either be set to 'ok' (in which case
+                                               # we return $candidate), or $ret will be set to
+                                               # the correct value (in which case we return $ret).
 
     unless($ret eq 'ok') {
       $Math::FakeDD::REPRO_PREC = "> $prec";
@@ -342,8 +345,8 @@ sub dd_repro {
   }
 
   $Math::FakeDD::REPRO_PREC = $prec;
-  return '-' . $can if $neg;
-  return $can;
+  return '-' . $candidate if $neg;
+  return $candidate;
 }
 
 sub _decrement {
